﻿using System;

namespace SyumasGen
{
    /// <summary>
    /// ランキング情報
    /// </summary>
    internal class RankingData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public RankingData(string[] s)
        {
            int i = 0;
            this.Rank = Convert.ToInt32(s[i++]);
            this.Mark = Convert.ToString(s[i++] ?? "");
            this.DiffRank = Convert.ToInt32(s[i++]);
            this.RankStat = Convert.ToString(s[i++] ?? "");
            this.StartSec = Convert.ToSingle(s[i++]);
            this.LengthSec = Convert.ToSingle(s[i++]);
            this.VideoId = Convert.ToString(s[i++] ?? "");
            this.FileName = Convert.ToString(s[i++] ?? "");
            this.Title = Convert.ToString(s[i++] ?? "");
            this.Pts = Convert.ToDecimal(s[i++]);
            this.Mylist = Convert.ToDecimal(s[i++]);
            this.Play = Convert.ToDecimal(s[i++]);
            this.Author = Convert.ToString(s[i++] ?? "");
            this.Date = Convert.ToDateTime(s[i++]);
            this.Remarks = Convert.ToString(s[i++] ?? "");
            this.FrameYOffset = Convert.ToInt32(s[i++]);
            this.PtsColor = Convert.ToString(s[i++] ?? "");
            this.MylistColor = Convert.ToString(s[i++] ?? "");
            this.PlayColor = Convert.ToString(s[i++] ?? "");
        }

        /// <summary>順位</summary>
        public int Rank { get; set; }

        /// <summary>ランク上下識別文字</summary>
        public string Mark { get; set; }

        /// <summary>先週からの順位差</summary>
        public int DiffRank { get; set; }

        /// <summary>変動</summary>
        public string RankStat { get; set; }

        /// <summary>動画開始秒数</summary>
        public float StartSec { get; set; }

        /// <summary>動画紹介秒数</summary>
        public float LengthSec { get; set; }

        /// <summary>動画ID</summary>
        public string VideoId { get; set; }

        /// <summary>ファイル名</summary>
        public string FileName { get; set; }

        /// <summary>動画タイトル</summary>
        public string Title { get; set; }

        /// <summary>点数</summary>
        public decimal Pts { get; set; }

        /// <summary>マイリスト登録数</summary>
        public decimal Mylist { get; set; }

        /// <summary>再生数</summary>
        public decimal Play { get; set; }

        /// <summary>作者</summary>
        public string Author { get; set; }

        /// <summary>投稿日</summary>
        public DateTime Date { get; set; }

        /// <summary>補足</summary>
        public string Remarks { get; set; }

        /// <summary>フレームYオフセット</summary>
        public int FrameYOffset { get; set; }

        /// <summary>Pts表示色</summary>
        public string PtsColor { get; set; }

        /// <summary>マイリスト登録表示色</summary>
        public string MylistColor { get; set; }

        /// <summary>再生表示色</summary>
        public string PlayColor { get; set; }
    }

    /// <summary>
    /// ピックアップ情報
    /// </summary>
    internal class PickupData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public PickupData(string[] s)
        {
            int i = 0;
            this.Number = Convert.ToInt32(s[i++]);
            this.StartSec = Convert.ToSingle(s[i++]);
            this.LengthSec = Convert.ToSingle(s[i++]);
            this.VideoId = Convert.ToString(s[i++] ?? "");
            this.Title = Convert.ToString(s[i++] ?? "");
            this.Author = Convert.ToString(s[i++] ?? "");
            this.Date = Convert.ToDateTime(s[i++]);
            this.SetRemarks(0, Convert.ToString(s[i++] ?? ""));
            this.SetRemarks(1, Convert.ToString(s[i++] ?? ""));
            this.SetRemarks(2, Convert.ToString(s[i++] ?? ""));
        }

        /// <summary>番号</summary>
        public int Number { get; set; }

        /// <summary>動画開始秒数</summary>
        public float StartSec { get; set; }

        /// <summary>動画紹介秒数</summary>
        public float LengthSec { get; set; }

        /// <summary>動画ID</summary>
        public string VideoId { get; set; }

        /// <summary>動画タイトル</summary>
        public string Title { get; set; }

        /// <summary>作者</summary>
        public string Author { get; set; }

        /// <summary>投稿日</summary>
        public DateTime Date { get; set; }

        /// <summary>補足</summary>
        private string[] _remarks = new string[3];

        public string GetRemarks(int i)
        {
            return _remarks[i];
        }
        public void SetRemarks(int i, string s)
        {
            _remarks[i] = s;
        }
    }

    /// <summary>
    /// 順位カットイン情報
    /// </summary>
    internal class CutInData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public CutInData(string[] s)
        {
            int i = 0;
            this.Mark = Convert.ToString(s[i++] ?? "");
            this.Week = Convert.ToString(s[i++] ?? "");
            this.Rank = Convert.ToString(s[i++] ?? "");
            this.Pts = Convert.ToDecimal(s[i++]);
            this.Diff = Convert.ToString(s[i++] ?? "");
            this.Remarks = Convert.ToString(s[i++] ?? "");
        }

        /// <summary>識別用</summary>
        public string Mark { get; set; }

        /// <summary>週</summary>
        public string Week { get; set; }

        /// <summary>順位</summary>
        public string Rank { get; set; }

        /// <summary>pts</summary>
        public Decimal Pts { get; set; }

        /// <summary>差</summary>
        public string Diff { get; set; }

        /// <summary>補足</summary>
        public string Remarks { get; set; }
    }

    /// <summary>
    /// 除外動画情報
    /// </summary>
    internal class JogaiData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public JogaiData(string[] s)
        {
            int i = 0;
            this.Category = Convert.ToString(s[i++] ?? "");
            this.Title = Convert.ToString(s[i++] ?? "");
            this.Pts = Convert.ToDecimal(s[i++]);
            this.Mylist = Convert.ToDecimal(s[i++]);
            this.Play = Convert.ToDecimal(s[i++]);
            this.Author = Convert.ToString(s[i++] ?? "");
            this.VideoId = Convert.ToString(s[i++] ?? "");
            this.Date = Convert.ToDateTime(s[i++]);
        }

        /// <summary>除外理由</summary>
        public string Category { get; set; }

        /// <summary>タイトル</summary>
        public string Title { get; set; }

        /// <summary>点数</summary>
        public decimal Pts { get; set; }

        /// <summary>マイリスト登録数</summary>
        public decimal Mylist { get; set; }

        /// <summary>再生数</summary>
        public decimal Play { get; set; }

        /// <summary>作者</summary>
        public string Author { get; set; }

        /// <summary>動画ID</summary>
        public string VideoId { get; set; }

        /// <summary>投稿日</summary>
        public DateTime Date { get; set; }
    }

    /// <summary>
    /// 集計概要データ
    /// </summary>
    internal class SummaryData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public SummaryData(string[] s)
        {
            int i = 0;
            this.Name = Convert.ToString(s[i++] ?? "");
            this.ThisWeek = Convert.ToDecimal(s[i++]);
            this.LastWeekDiff = Convert.ToDecimal(s[i++]);
            this.NewVideos = Convert.ToDecimal(s[i++]);
        }

        /// <summary>項目名</summary>
        public string Name { get; set; }

        /// <summary>今週</summary>
        public decimal ThisWeek { get; set; }

        /// <summary>先週比</summary>
        public decimal LastWeekDiff { get; set; }

        /// <summary>新作数</summary>
        public decimal NewVideos { get; set; }
    }

    /// <summary>
    /// 出演回数データ
    /// </summary>
    internal class StageData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public StageData(string[] s)
        {
            int i = 0;
            this.Name = Convert.ToString(s[i++] ?? "");
            this.Solo = Convert.ToInt32(s[i++]);
            this.SoloColor = Convert.ToString(s[i++] ?? "");
            this.Pair = Convert.ToInt32(s[i++]);
            this.PairColor = Convert.ToString(s[i++] ?? "");
            this.Other = Convert.ToInt32(s[i++]);
            this.Center = Convert.ToInt32(s[i++]);
            this.OtherColor = Convert.ToString(s[i++] ?? "");
            this.Total = Convert.ToInt32(s[i++]);
            this.TotalColor = Convert.ToString(s[i++] ?? "");
        }

        /// <summary>名前</summary>
        public string Name { get; set; }

        /// <summary>ソロ</summary>
        public int Solo { get; set; }

        /// <summary>ソロ表示色</summary>
        public string SoloColor { get; set; }

        /// <summary>ペア</summary>
        public int Pair { get; set; }

        /// <summary>ペア表示色</summary>
        public string PairColor { get; set; }

        /// <summary>他</summary>
        public int Other { get; set; }

        /// <summary>センター</summary>
        public int Center { get; set; }

        /// <summary>他表示色</summary>
        public string OtherColor { get; set; }

        /// <summary>合計</summary>
        public int Total { get; set; }

        /// <summary>合計表示色</summary>
        public string TotalColor { get; set; }
    }

    /// <summary>
    /// 登録数及び再生数の順位
    /// </summary>
    internal class PlayRankData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public PlayRankData(string[] s)
        {
            int i = 0;
            this.Title = Convert.ToString(s[i++]);
            this.Rank = Convert.ToInt32(s[i++]);
            this.MylistRank = Convert.ToInt32(s[i++]);
            this.Mylist = Convert.ToDecimal(s[i++]);
            this.PlayRank = Convert.ToInt32(s[i++]);
            this.Play = Convert.ToDecimal(s[i++]);
        }

        /// <summary>タイトル</summary>
        public string Title { get; set; }

        /// <summary>順位</summary>
        public int Rank { get; set; }

        /// <summary>登録順位</summary>
        public int MylistRank { get; set; }

        /// <summary>登録数</summary>
        public decimal Mylist { get; set; }

        /// <summary>再生順位</summary>
        public int PlayRank { get; set; }

        /// <summary>再生数</summary>
        public decimal Play { get; set; }
    }

    /// <summary>
    /// ランキングリストデータ
    /// </summary>
    internal class OutRangeData
    {
        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="s"></param>
        public OutRangeData(string[] s)
        {
            int i = 0;
            this.Rank = Convert.ToInt32(s[i++]);
            this.Diff = Convert.ToString(s[i++] ?? "");
            this.Pts = Convert.ToDecimal(s[i++]);
            this.Jogai = Convert.ToString(s[i++] ?? "");
            this.Title = Convert.ToString(s[i++] ?? "");
        }

        /// <summary>順位</summary>
        public int Rank { get; set; }

        /// <summary>変動</summary>
        public string Diff { get; set; }

        /// <summary>点数</summary>
        public decimal Pts { get; set; }

        /// <summary>除外</summary>
        public string Jogai { get; set; }

        /// <summary>タイトル</summary>
        public string Title { get; set; }
    }
}
