﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// 除外リスト画像
    /// </summary>
    class ImageJogai
    {
        /// <summary>
        /// 除外リスト画像を描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data"></param>
        /// <param name="option"></param>
        /// <param name="startIndex"></param>
        /// <returns></returns>
        internal static int Draw(Graphics g, DataList dataList, Settings option, int startIndex)
        {
            List<JogaiData> list = dataList.JogaiList;

            // 描画エリアのクリア（背景色は黄色）
            g.Clear(Color.FromArgb(255, ImageGen._BackColorYellow));

            // フォントの設定
            TextInfoData textInfo = option.TextInfoList[TextInfoKind.JogaiText];
            Font textFont = new Font(textInfo.FontName, textInfo.FontSize, FontStyle.Bold);

            // タイトル描画
            ImageGen.DrawText(g, "┗圏内に入った除外カテゴリ作品┣", textFont, Brushes.Black, 0, 10, Align.ScreenCenter);

            // リスト描画
            int endIndex = 0;
            int y = 25;

            for (int i = startIndex; i < list.Count; i++)
            {
                endIndex = i;

                // 改ページ記号が現れたら処理終了
                if (list[i].Category == "*") break;

                // 除外理由が変わった時に除外理由を描画
                if (i == startIndex || list[i - 1].Category != list[i].Category)
                {
                    y += 2;
                    ImageGen.DrawText(g, "★" + list[i].Category, textFont, Brushes.Red, 10, y, Align.Left);
                    y += 15;
                }

                // タイトル
                ImageGen.DrawText(g, list[i].Title, textFont, Brushes.Black, 10, y, Align.Left);

                // ポイント
                y += 13;
                ImageGen.DrawText(g, list[i].Pts.ToString() + "pts", textFont, Brushes.Black, 10, y, Align.Left);

                // 登録
                ImageGen.DrawText(g, "登録:" + list[i].Mylist.ToString(), textFont, Brushes.Black, 70, y, Align.Left);

                // 再生
                ImageGen.DrawText(g, "再生:" + list[i].Play.ToString(), textFont, Brushes.Black, 140, y, Align.Left);

                // 作者
                ImageGen.DrawText(g, list[i].Author, textFont, Brushes.Black, 340, y, Align.Right);

                // 動画ID
                ImageGen.DrawText(g, list[i].VideoId, textFont, Brushes.Black, 345, y, Align.Left);

                // 投稿日
                ImageGen.DrawText(g, list[i].Date.ToString("[yyyy/MM/dd]"), textFont, Brushes.Black, 415, y, Align.Left);

                y += 14;
            }

            // リソース開放
            textFont.Dispose();

            return ++endIndex;
        }
    }
}
