﻿using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// 圏外リスト画像
    /// </summary>
    class ImageOutRangeList
    {
        /// <summary>
        /// 圏外リスト画像を描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data"></param>
        /// <param name="option"></param>
        /// <param name="startIndex"></param>
        /// <returns></returns>
        internal static int Draw(Graphics g, DataList dataList, Settings option, int startIndex)
        {
            List<OutRangeData> list = dataList.OutRangeList;

            // 描画エリアのクリア（背景色は黄色）
            g.Clear(Color.FromArgb(255, ImageGen._BackColorYellow));

            // フォントの設定
            TextInfoData textInfo = option.TextInfoList[TextInfoKind.OutRangeText];
            Font textFont = new Font(textInfo.FontName, textInfo.FontSize, FontStyle.Bold);

            // タイトル描画
            string title = "┗" + dataList.OutRangeList[0].Title +"┣";
            ImageGen.DrawText(g, title, textFont, Brushes.Black, 0, 10, Align.ScreenCenter);

            // 項目
            int y = 30;
            ImageGen.DrawText(g, "順位", textFont, Brushes.Black, 25, y, Align.Right);
            ImageGen.DrawText(g, "変動", textFont, Brushes.Black, 32, y, Align.Left);
            ImageGen.DrawText(g, "pts", textFont, Brushes.Black, 105, y, Align.Right);
            ImageGen.DrawText(g, "タイトル", textFont, Brushes.Black, 125, y, Align.Left);

            // リスト描画
            int endIndex = 0;
            y = 50;

            for (int i = startIndex; i < startIndex + 20 && i < list.Count ; i++)
            {
                endIndex = i;

                // 順位
                ImageGen.DrawText(g, list[i].Rank.ToString(), textFont, Brushes.Black, 25,y, Align.Right);

                // 変動
                ImageGen.DrawText(g, list[i].Diff, textFont, Brushes.Black, 27, y, Align.Left);

                // ポイント
                ImageGen.DrawText(g, list[i].Pts.ToString(), textFont, Brushes.Black, 105, y, Align.Right);

                // 除外
                ImageGen.DrawText(g, list[i].Jogai, textFont, Brushes.Red, 108, y, Align.Left);

                // タイトル
                ImageGen.DrawText(g, list[i].Title, textFont, Brushes.Black, 125, y, Align.Left);

                y += 16;
            }

            // リソース開放
            textFont.Dispose();

            return ++endIndex;
        }
    }
}
