﻿using System.Drawing;
using System.IO;
using System.Windows.Forms;

namespace SyumasGen
{
    /// <summary>
    /// ピックアップのフレーム画像
    /// </summary>
    class ImagePickupFrame
    {
        /// <summary>
        /// ピックアップの動画情報フレームを描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data1"></param>
        /// <param name="option"></param>
        /// <param name="index"></param>
        internal static void DrawVideoInfo(Graphics g, DataList dataList, Settings option, int index)
        {
            PickupData data = dataList.PickupList[index];

            // 描画エリアのクリア
            g.Clear(Color.FromArgb(0, Color.Black));

            // フレーム情報
            FrameInfoData frameData = option.FrameInfoList["P"];

            // フレーム画像描画
            string framePath = Path.Combine(Application.StartupPath, frameData.FrameImageFile);
            g.DrawImage(Image.FromFile(framePath), option.FramePos);

            // "Pickup"描画
            TextInfoData pickupInfoInfo = option.TextInfoList[TextInfoKind.PickupInfo];
            Point pickupPos = new Point(pickupInfoInfo.PosX, pickupInfoInfo.PosY);
            Font pickupFont = new Font(pickupInfoInfo.FontName, pickupInfoInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

            ImageGen.DrawFuchidoriText(g, "Pickup", pickupFont, Color.Purple, Color.White, 1.5f, pickupPos, Align.Left);

            pickupFont.Dispose();

            // ピックアップ番号描画
            TextInfoData numberInfo = option.TextInfoList[TextInfoKind.PickupNumber];
            Point numberPos = new Point(numberInfo.PosX, numberInfo.PosY);
            Point numberShadowPos = numberPos + new Size(3, 3);
            Font numberFont = new Font(numberInfo.FontName, numberInfo.FontSize, FontStyle.Bold | FontStyle.Italic, GraphicsUnit.Pixel);
            Color shadowColor = Color.FromArgb(128, Color.Black);
            string number = data.Number.ToString("00");

            ImageGen.DrawFuchidoriText(g, number, numberFont, shadowColor, shadowColor, 2.0f, numberShadowPos, Align.Left);
            ImageGen.DrawFuchidoriText(g, number, numberFont, Color.Purple, Color.White, 2.0f, numberPos, Align.Left);

            int numberWidth = (int)g.MeasureString(number, numberFont).Width;
            numberFont.Dispose();

            // タイトル描画
            TextInfoData titleInfo = option.TextInfoList[TextInfoKind.PickupTitle];
            Font titleFont = new Font(titleInfo.FontName, titleInfo.FontSize, FontStyle.Bold);
            int posX = -10 + numberWidth;

            ImageGen.DrawText(g, data.Title, titleFont, Brushes.Black, posX, titleInfo.PosY, Align.Left);

            titleFont.Dispose();

            // 作者名描画
            TextInfoData videoDataInfo = option.TextInfoList[TextInfoKind.PickupVideoData];
            Font videoDataFont = new Font(videoDataInfo.FontName, videoDataInfo.FontSize, FontStyle.Bold);

            int y = videoDataInfo.PosY;

            ImageGen.DrawText(g, data.Author, videoDataFont, Brushes.Black, 295, y, Align.Right);

            // 動画ID描画
            ImageGen.DrawText(g, data.VideoId, videoDataFont, Brushes.Black, 385, y, Align.Right);

            // 投稿日描画
            ImageGen.DrawText(g, data.Date.ToString("[yyyy/MM/dd]"), videoDataFont, Brushes.Black, 500, y, Align.Right);

            videoDataFont.Dispose();
        }

        /// <summary>
        /// ピックアップの解説情報フレームを描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data1"></param>
        /// <param name="option"></param>
        /// <param name="index"></param>
        internal static void DrawVideoExplain(Graphics g, DataList dataList, Settings option, int index, int page)
        {
            PickupData data = dataList.PickupList[index];

            // 描画エリアのクリア
            g.Clear(Color.FromArgb(0, Color.Black));

            // フレーム情報
            FrameInfoData frameData = option.FrameInfoList["P"];

            // フレーム画像描画
            string framePath = Path.Combine(Application.StartupPath, frameData.FrameImageFile);
            g.DrawImage(Image.FromFile(framePath), option.FramePos);

            // テキスト
            TextInfoData textInfo = option.TextInfoList[TextInfoKind.PickupText];
            Font textFont = new Font(textInfo.FontName, textInfo.FontSize, FontStyle.Bold);
            Point pos = new Point(textInfo.PosX, textInfo.PosY);

            //ImageGen.DrawText(g, data.GetRemarks(page), textFont, Brushes.Black, pos, Align.Left);
            g.DrawString(data.GetRemarks(page), textFont, Brushes.Black, new RectangleF(5, 307, ImageGen._BaseWidth - 5, 70));

            System.Diagnostics.Debug.WriteLine("---------");
            System.Diagnostics.Debug.WriteLine(data.GetRemarks(page).IndexOf("\n"));
            System.Diagnostics.Debug.WriteLine(data.GetRemarks(page).IndexOf("\r"));

            textFont.Dispose();
        }
    }
}
