﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Windows.Forms;
using System.Collections.Generic;

namespace SyumasGen
{
    /// <summary>
    /// 順位カットイン画像
    /// </summary>
    class ImageRankCutIn
    {
        /// <summary>
        /// 順位カットイン画像を描画します。
        /// </summary>
        /// <param name="g"></param>
        /// <param name="data"></param>
        /// <param name="option"></param>
        internal static void Draw(Graphics g, DataList dataList, Settings option, int index)
        {
            CutInData data = dataList.TakagiList[index];

            // 描画エリアのクリア
            g.Clear(Color.FromArgb(0, Color.Black));

            switch (data.Mark)
            {
                case "A":
                    // 順位
                    TextInfoData rankInfo = option.TextInfoList[TextInfoKind.TakagiRank];
                    Font rankFont = new Font(rankInfo.FontName, rankInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Rank, rankFont, Color.White, Color.Black, 1.0f, 0, rankInfo.PosY, Align.ScreenCenter);

                    rankFont.Dispose();

                    // 週
                    TextInfoData weekInfo = option.TextInfoList[TextInfoKind.TakagiWeek];
                    Font weekFont = new Font(weekInfo.FontName, weekInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Week, weekFont, Color.White, Color.Black, 1.0f, 0, weekInfo.PosY, Align.ScreenCenter);

                    weekFont.Dispose();

                    // 補足
                    if (data.Remarks != "")
                    {
                        TextInfoData remarksInfo = option.TextInfoList[TextInfoKind.TakagiRemarks];
                        Font remarksFont = new Font(remarksInfo.FontName, remarksInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);
                        Point remarksPos = new Point(remarksInfo.PosX, remarksInfo.PosY);

                        ImageGen.DrawText(g, data.Remarks, remarksFont, Brushes.Black, remarksPos, Align.Left);

                        remarksFont.Dispose();
                    }

                    break;

                case "B":
                    int offsetX = 300;

                    // 週
                    TextInfoData weekInfo2 = option.TextInfoList[TextInfoKind.TakagiTop3Week];
                    Font weekFont2 = new Font(weekInfo2.FontName, weekInfo2.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Week, weekFont2, Color.White, Color.Black, 1.0f, offsetX, weekInfo2.PosY, Align.Center);

                    weekFont2.Dispose();

                    // 順位
                    TextInfoData rankInfo2 = option.TextInfoList[TextInfoKind.TakagiTop3Rank];
                    Font rankFont2 = new Font(rankInfo2.FontName, rankInfo2.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Rank, rankFont2, Color.White, Color.Black, 1.0f, offsetX, rankInfo2.PosY, Align.Center);

                    rankFont2.Dispose();

                    // pts
                    TextInfoData ptsInfo = option.TextInfoList[TextInfoKind.TakagiTop3Pts];
                    Font ptsFont = new Font(ptsInfo.FontName, ptsInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Pts + "pts", ptsFont, Color.White, Color.Black, 1.0f, offsetX, ptsInfo.PosY, Align.Center);

                    ptsFont.Dispose();

                    // 差
                    TextInfoData diffInfo = option.TextInfoList[TextInfoKind.TakagiTop3Diff];
                    Font diffFont = new Font(diffInfo.FontName, diffInfo.FontSize, FontStyle.Bold, GraphicsUnit.Pixel);

                    ImageGen.DrawFuchidoriText(g, data.Diff, diffFont, Color.White, Color.Black, 1.0f, offsetX, diffInfo.PosY, Align.Center);

                    diffFont.Dispose();

                    break;

                default:
                    throw new Exception("社長カットイン情報に無効な識別子が指定されています。");
            }
        }
    }
}
