﻿using System;
using System.IO;
using System.Windows.Forms;

namespace SyumasGen
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// 実行ボタンクリック
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void execButton_Click(object sender, EventArgs e)
        {
            if (rankingFileText.Text == "")
            {
                MessageBox.Show(this, "ファイルを入力してください。", "エラー", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            if (avsFileText.Text == "")
            {
                MessageBox.Show(this, "ファイルを入力してください。", "エラー", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            // 設定ファイル読み込み
            string iniPath = Path.Combine(Application.StartupPath, "Settings.ini");
            Settings settings = new Settings();
            settings.ReadIniFile(iniPath);

            // Excelファイル読み込み
            DataList dataList = new DataList();

            try
            {
                string excelPath = Path.Combine(Application.StartupPath, rankingFileText.Text);
                dataList.ReadFile(excelPath, settings);
            }
            catch (Exception ex)
            {
                ShowError("ランキングデータファイルを読み込み中にエラーが発生しました。", ex);
                return;
            }

            // 画像生成
            try
            {
                using (ImageGen gen = new ImageGen())
                {
                    gen.Genarate(dataList, settings);
                }
            }
            catch (Exception ex)
            {
                ShowError("画像ファイルの生成でエラーが発生しました。", ex);
                return;
            }

            // スクリプトファイル生成
            try
            {
                AvsFileGenerator.SaveScript(avsFileText.Text, dataList.RankingList, settings);
            }
            catch (Exception ex)
            {
                ShowError("スクリプトファイルの生成でエラーが発生しました。", ex);
                return;
            }

            MessageBox.Show(this, "完了しました。", "完了", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        /// <summary>
        /// ランキングExcelファイル参照ボタンクリック
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void rankingFileBrowseButton_Click(object sender, EventArgs e)
        {
            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                rankingFileText.Text = openFileDialog.FileName;
            }
        }

        /// <summary>
        /// 生成先スクリプトファイル参照ボタンクリック
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void avsFileBrowseButton_Click(object sender, EventArgs e)
        {
            if (saveFileDialog.ShowDialog() == DialogResult.OK)
            {
                avsFileText.Text = saveFileDialog.FileName;
            }
        }

        /// <summary>
        /// エラーダイアログを表示します。
        /// </summary>
        /// <param name="msg"></param>
        /// <param name="ex"></param>
        private void ShowError(string msg, Exception ex)
        {
            MessageBox.Show(this, msg + "\n" + ex.Message + "\n\n" + ex.StackTrace, "エラー", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            this.Text += " Ver." + Application.ProductVersion;
        }
    }
}
